@@ -2,7 +2,7 @@ module Declarative
   class DeepDup
     def self.call(args)
       return Array[*dup_items(args)] if args.is_a?(Array)
-      return Hash[dup_items(args)] if args.is_a?(Hash)
+      return ::Hash[dup_items(args)] if args.is_a?(::Hash)
       args
     end
 
@@ -11,4 +11,4 @@ module Declarative
       arr.to_a.collect { |v| call(v) }
     end
   end
-end
\ No newline at end of file
+end
