@@ -1,4 +1,14 @@
 module Declarative
+  def self.Inspect(obj)
+    string = obj.inspect
+
+    if obj.is_a?(Proc)
+      elements = string.split("/")
+      string = "#{elements.first}#{elements.last}"
+    end
+    string.gsub(/0x\w+/, "")
+  end
+
   module Inspect
     def inspect
       string = super
@@ -35,4 +45,4 @@ module Declarative
       super.extend(Declarative::Inspect)
     end
   end
-end
\ No newline at end of file
+end
